import QtQuick 1.0
import QtMultimediaKit 1.1
import com.nokia.meego 1.0

Page
{
    orientationLock: PageOrientation.LockPortrait

    Rectangle
    {
        id: incomingCallRect
        width: 480
        height: 854
        color: "black"

        Connections
        {
            target: appWindow
            onCallerChanged:
            {
                callerId.text = callerName;
            }
            onPlaceCall:
            {
                callerId.color = "white";

                bottomButtonsSet1.visible = true;
                bottomButtonsSet2.visible = false;

                rejectButton2.visible = false;
                muteButton.visible = true;

                incomingCallTextTimer.start();
                nokiaRingtone.m_loop = true;
                nokiaRingtone.play();
                nokiaFeedback.start();
            }
        }
        Timer
        {
            id: incomingCallTextTimer
            interval: 500
            repeat: true
            onTriggered:
            {
                ++incomingCallText.noOfDots;
                if(incomingCallText.noOfDots > 3)
                {
                    incomingCallText.noOfDots = 0;
                }
                incomingCallText.text = "Incoming Call"
                for(var i = 0; i < incomingCallText.noOfDots; ++i)
                {
                    incomingCallText.text += ".";
                }
            }
        }

        Rectangle
        {
            width: parent.width
            height: 170
            color: "black"
            y: parent.height / 2 - height;
            anchors.horizontalCenter: parent.horizontalCenter
            Rectangle
            {
                id: callerIconRect
                anchors.verticalCenter: parent.verticalCenter
                x: acceptButton.x;
                smooth: true
                width:64
                height:64
                color: "black"

                Image
                {
                    id: callerIcon
                    anchors.centerIn: parent
                    smooth: true
                    source: "assets/Icon.png"
                }
            }

            Text
            {
                id: callerIconText
                anchors.centerIn:callerIconRect
                font.pixelSize: 36
                font.bold: true
                text: "FC"
                color: "white"
            }

            Text
            {
                id: callerId
                x: callerIconRect.x + callerIconRect.width + 20
                y: callerIconRect.y
                font.pixelSize: 36
                text: ""
                color: "white"
            }

            Text
            {
                property int noOfDots: 0;

                id: incomingCallText
                x: callerId.x
                y: callerIconRect.y + callerIconRect.height - incomingCallText.height
                font.pixelSize: 16
                font.bold: false
                text: "Incoming Call"
                color: "white"
                Connections
                {
                    target:appWindow
                    onPlaceCall:
                    {
                        incomingCallText.visible = true;
                    }
                    onAcceptCall:
                    {
                        incomingCallText.visible = false;
                    }
                }
            }

            Text
            {
                id: callTimerText
                x: callerId.x
                y: callerIconRect.y + callerIconRect.height - incomingCallText.height
                font.pixelSize: 18
                font.bold: false
                text: "00:00"
                color: "#888888"
                visible: false
                Connections
                {
                    target:appWindow
                    onPlaceCall:
                    {
                        callTimerText.visible = false;
                    }
                    onAcceptCall:
                    {
                        console.log("Showing Timer")
                        incomingCallText.visible = false;
                        callTimerText.visible = true;
                    }
                    onCallSecsChanged:
                    {
                        var display;

                        var secs = callSecs % 60;
                        var displaySecs = (secs < 10) ? "0" + secs : secs;

                        var mins = Math.floor(callSecs / 60);
                        var displayMins = (mins < 10) ? "0" + mins : mins;

                        callTimerText.text = displayMins + ":" + displaySecs;
                    }
                }
            }

            Rectangle
            {
                id: callIconRect
                x: rejectButton.x + rejectButton.width - callIconRect.width;
                y: callerIconRect.y
                smooth: true
                width:19
                height:19
                color: "black"

                Image
                {
                    id: callIcon
                    anchors.centerIn: parent
                    smooth: true
                    source: "assets/CallIcon.png"
                }
            }
        }
        Rectangle
        {
            id: bottomButtonsSet1
            width:parent.width
            height: 120
            color:"black"
            anchors.horizontalCenter:parent.horizontalCenter
            y: parent.height / 2
            visible: true
            //Button
            Rectangle
            {
                id: acceptButton
                anchors.verticalCenter: parent.verticalCenter
                width: 200
                x: parent.width / 2 - width - 15
                color: "black"
                Image
                {
                    id: acceptButtonBg
                    anchors.centerIn: parent
                    smooth: true
                    source: "assets/AcceptButton.png"

                    MouseArea
                    {
                        id: acceptButtonMouseArea
                        width:parent.width
                        height:parent.height
                        onPressed:
                        {
                            acceptButtonBg.opacity = 0.5;
                        }
                        onReleased:
                        {
                            incomingCallTextTimer.stop();

                            acceptButtonBg.opacity = 1.0;

                            appWindow.callSecs = 0;
                            appWindow.callSecsChanged(0);
                            callTimer.start();
                            appWindow.acceptCall();

                            bottomButtonsSet1.visible = false;
                            bottomButtonsSet2.visible = true;

                            rejectButton2.visible = true;
                            muteButton.visible = false;

                            callerId.color = "green"

                            nokiaRingtone.m_loop = false;
                            nokiaRingtone.stop();
                            nokiaFeedback.stop();
                        }
                    }
                }
            }
            //Button
            Rectangle
            {
                id: rejectButton
                anchors.verticalCenter: parent.verticalCenter
                width: 200
                x: parent.width / 2 + 15
                color:"black"
                Image
                {
                    id: rejectButtonBg
                    anchors.centerIn: parent
                    smooth: true
                    source: "assets/RejectButton.png"

                    MouseArea
                    {
                        id: rejectButtonMouseArea
                        width:parent.width
                        height:parent.height
                        onPressed:
                        {
                            rejectButtonBg.opacity = 0.5;
                        }
                        onReleased:
                        {
                            rejectButtonBg.opacity = 1.0;

                            appWindow.pageStack.pop();
                            nokiaRingtone.m_loop = false;
                            nokiaRingtone.stop();
                            nokiaFeedback.stop();
                        }
                    }
                }
            }
        }
//------------------------- Buttons from left to right after answering
        Rectangle
        {
            id: bottomButtonsSet2
            width:parent.width
            height: 120
            color:"black"
            anchors.horizontalCenter:parent.horizontalCenter
            y: parent.height / 2
            visible: false
            //Line
            Rectangle
            {
                width: parent.width - 20
                height: 1
                anchors.horizontalCenter: parent.horizontalCenter
                color: "#444444"
                y: 0
            }

            //Button
            Rectangle
            {
                id: muteButtonSmall
                anchors.verticalCenter: parent.verticalCenter
                width: 62
                height: 63
                x: parent.width / 2 - width - 30
                color: "black"
                Image
                {
                    id: muteButtonSmallBg
                    anchors.centerIn: parent
                    smooth: true
                    source: "assets/MuteButtonSml.png"

                    MouseArea
                    {
                        id: muteButtonSmallMouseArea
                        width:parent.width
                        height:parent.height
                        onPressed:
                        {
                            muteButtonSmallBg.opacity = 0.5;
                        }
                        onReleased:
                        {
                            muteButtonSmallBg.opacity = 1.0;
                        }
                    }
                }
                Text
                {
                    id: muteButtonSmallCaption
                    text: "Mute"
                    color: "#444444"
                    font.pixelSize: 20
                    font.bold: false
                    x: (muteButtonSmallBg.x + muteButtonSmallBg.width / 2) - (muteButtonSmallCaption.width / 2)
                    y: muteButtonSmallBg.y + muteButtonSmallBg.height + 10
                }
            }
            //Button
            Rectangle
            {
                id: speakerButtonSmall
                anchors.verticalCenter: parent.verticalCenter
                width: 62
                height: 63
                x: (parent.width / 2) - width - muteButtonSmall.width - 90
                color: "black"
                Image
                {
                    id: speakerButtonSmallBg
                    anchors.centerIn: parent
                    smooth: true
                    source: "assets/SpeakerButtonSml.png"

                    MouseArea
                    {
                        id: speakerButtonSmallMouseArea
                        width:parent.width
                        height:parent.height
                        onPressed:
                        {
                            speakerButtonSmallBg.opacity = 0.5;
                        }
                        onReleased:
                        {
                            speakerButtonSmallBg.opacity = 1.0;
                        }
                    }
                }
                Text
                {
                    id: speakerButtonSmallCaption
                    text: "Speaker"
                    color: "#444444"
                    font.pixelSize: 20
                    font.bold: false
                    x: (speakerButtonSmallBg.x + speakerButtonSmallBg.width / 2) - (speakerButtonSmallCaption.width / 2)
                    y: speakerButtonSmallBg.y + speakerButtonSmallBg.height + 10
                }
            }
            //Button
            Rectangle
            {
                id: holdButtonSmall
                anchors.verticalCenter: parent.verticalCenter
                width: 62
                height: 63
                x: (parent.width / 2) + 30
                color: "black"
                Image
                {
                    id: holdButtonSmallBg
                    anchors.centerIn: parent
                    smooth: true
                    source: "assets/HoldButtonSml.png"
                    MouseArea
                    {
                        id: holdButtonSmallMouseArea
                        width:parent.width
                        height:parent.height
                        onPressed:
                        {
                            holdButtonSmallBg.opacity = 0.5;
                        }
                        onReleased:
                        {
                            holdButtonSmallBg.opacity = 1.0;
                        }
                    }
                }
                Text
                {
                    id: holdButtonSmallCaption
                    text: "Hold"
                    color: "#444444"
                    font.pixelSize: 20
                    font.bold: false
                    x: (holdButtonSmallBg.x + holdButtonSmallBg.width / 2) - (holdButtonSmallCaption.width / 2)
                    y: holdButtonSmallBg.y + holdButtonSmallBg.height + 10
                }
            }
            //Button
            Rectangle
            {
                id: dialerButtonSmall
                anchors.verticalCenter: parent.verticalCenter
                width: 62
                height: 63
                x: (parent.width / 2) + holdButtonSmall.width + 90
                color: "black"
                Image
                {
                    id: dialerButtonSmallBg
                    anchors.centerIn: parent
                    smooth: true
                    source: "assets/KeypadButtonSml.png"

                    MouseArea
                    {
                        id: dialerButtonSmallMouseArea
                        width:parent.width
                        height:parent.height
                        onPressed:
                        {
                            dialerButtonSmallBg.opacity = 0.5;
                        }
                        onReleased:
                        {
                            dialerButtonSmallBg.opacity = 1.0;
                        }
                    }
                }
                Text
                {
                    id: dialerButtonSmallCaption
                    text: "Keypad"
                    color: "#444444"
                    font.pixelSize: 20
                    font.bold: false
                    x: (dialerButtonSmallBg.x + dialerButtonSmallBg.width / 2) - (dialerButtonSmallCaption.width / 2)
                    y: dialerButtonSmallBg.y + dialerButtonSmallBg.height + 10
                }
            }
        }
        //------------------------- END Buttons from left to right after answering
        Rectangle
        {
            width:parent.width
            height:200
            anchors.horizontalCenter:parent.horizontalCenter
            y: parent.height - height
            color: "black"
            //Button
            Rectangle
            {
                id: muteButton
                width: 480
                height: 65
                anchors.verticalCenter:parent.verticalCenter
                x: parent.width / 2 - width / 2
                color:"black"
                Image
                {
                    id: muteButtonBg
                    anchors.centerIn: parent
                    smooth: true
                    source: "assets/MuteButton.png"

                    MouseArea
                    {
                        id: muteButtonMouseArea
                        width:parent.width
                        height:parent.height
                        onPressed:
                        {
                            muteButtonBg.opacity = 0.5;
                        }
                        onReleased:
                        {
                            muteButtonBg.opacity = 1.0;
                        }
                    }
                }
            }
            Rectangle
            {
                id: rejectButton2
                width: 480
                height: 65
                anchors.verticalCenter:parent.verticalCenter
                x: parent.width / 2 - width / 2
                color:"black"
                visible: false
                Image
                {
                    id: rejectButton2Bg
                    anchors.centerIn: parent
                    smooth: true
                    source: "assets/RejectButton.png"

                    MouseArea
                    {
                        id: rejectButton2MouseArea
                        width:parent.width
                        height:parent.height
                        onPressed:
                        {
                            rejectButton2Bg.opacity = 0.5;
                        }
                        onReleased:
                        {
                            rejectButton2Bg.opacity = 1.0;

                            appWindow.pageStack.pop();
                            callTimer.stop();
                        }
                    }
                }
                Image
                {
                    id: menuButtonSmlBg
                    smooth: true
                    source: "assets/MenuButtonSml.png"
                    x: parent.width - 20 - menuButtonSmlBg.width
                    y: rejectButton2Bg.y + rejectButton2Bg.height - menuButtonSmlBg.height

                    MouseArea
                    {
                        id: menuButtonSmlBgMouseArea
                        width:parent.width
                        height:parent.height
                        onPressed:
                        {
                            menuButtonSmlBg.opacity = 0.5;
                        }
                        onReleased:
                        {
                            menuButtonSmlBg.opacity = 1.0;
                        }
                    }
                }
            }
        }
    }
}
