import QtQuick 1.1
import QtMobility.contacts 1.1
import com.nokia.meego 1.0



Page
{
    orientationLock: PageOrientation.LockPortrait

    Rectangle
    {
        width: 480
        height: 854

        Rectangle
        {
            id: middleZone
            width:480
            height:754
            y: topZone.y + topZone.heights
            color: "black"

            Component
            {
                id: contactDelegate
                Text
                {
                    property string entryName: model.contact.name.lastName !== "" ? model.contact.name.lastName + ", " + model.contact.name.firstName : model.contact.name.firstName
                    property string entryNumber: model.contact.phoneNumber.number === undefined ? "0" : model.contact.phoneNumber.number

                    id: entryText
                    text: entryName
                    font.pixelSize: 35
                    font.bold: true
                    color: "#666666"
                    width: middleZone.width
                    verticalAlignment: Text.AlignVCenter
                    height: 80
                    Component.onCompleted:
                    {
                        console.log("Loaded entryText")
                    }

                    MouseArea
                    {
                        id: itemMouseArea
                        width: parent.width
                        height: parent.height
                        onReleased:
                        {
                            console.log("Released on " + entryText.entryName + "," +
                                        entryText.entryRingToneUrl + "," +
                                        entryText.entryAvatarUrl + "," + index);
                            fakeContactList.currentIndex = index;
                            appWindow.callerChanged(entryText.entryName);
                            appWindow.numberChanged(entryText.entryNumber);
                            appWindow.pageStack.push(contactSelectedPage);
                        }
                    }

                    Connections
                    {
                        target:fakeContactList
                        onCurrentItemChanged:
                        {
                            if(fakeContactList.currentIndex == index)
                            {
                                entryText.color = "black";
                            }
                            else
                            {
                                entryText.color = "#666666";
                            }
                        }
                    }
                }
            }

            Rectangle
            {
                id: listWrapper
                width: 480
                height: parent.height - 250
                y: 50
                color: "black"

                ListView
                {
                    currentIndex: -1

                    id: fakeContactList
                    width: parent.width
                    height: parent.height

                    model: ContactModel
                    {
                        sortOrders:
                        [
                            SortOrder
                            {
                               detail:ContactDetail.Name
                               field:Name.FirstName
                               direction:Qt.AscendingOrder
                            }
                        ]
                    }
                    delegate: contactDelegate
                    highlightMoveDuration: 1
                    highlightResizeDuration: 1
                    highlight: Rectangle
                    {
                        width: parent.width
                        color: "lightblue"
                    }
                }

                Rectangle
                {
                    width:parent.width
                    height:1
                    color: "grey"
                }
            }

            Rectangle
            {
                width:parent.width
                height:300
                x: 0
                y: listWrapper.y + listWrapper.height
                color: "black"
                Gradient
                {
                    GradientStop
                    {
                        color: "black"
                        position: 0.0
                    }
                    GradientStop
                    {
                        color: "#666666"
                        position: 0.8
                    }
                }

                Text
                {
                    y: 10
                    font.pixelSize: 30
                    text: "OR"
                    color: "#009696"
                    anchors.horizontalCenter: parent.horizontalCenter
                }

                Button
                {
                    id: btnPrivateCall
                    width: parent.width - 30
                    height: 150
                    anchors.horizontalCenter: parent.horizontalCenter
                    y: 70
                    font.pixelSize: 30
                    text: "<font color='#666666'>Activate Private<br />CALL IMMEDIATELY</font>"
                    onClicked:
                    {
                        appWindow.callerChanged("Private Number");
                        appWindow.numberChanged("");
                        appWindow.placeCall();
                        appWindow.pageStack.push(incomingCallPage);
                    }
                }
                Rectangle
                {
                    width:parent.width
                    height:1
                    color: "grey"
                }
            }
        }

        Rectangle
        {
            id: topZone
            width: 480
            height: 50
            color: "black"
            Label
            {
                font.pixelSize: 30
                id: lblChoose
                y:10
                color: "#009696"
                anchors.horizontalCenter: parent.horizontalCenter
                text: "Choose a Contact"
            }
        }
    }
}
